*** This file replicates the results for tables A2 and A3 in the puzzling paper
*** It estimates the model with various specifications and with various sample sizes

*There are 1,226 observations in the master data file
*sandiego2a.dta has 1,077 observations.  We get this by dropping:
*  9 non-housekeeping HH, 8 group homes, 83 homeless, and 48 with invalid food data
* We also drop id # 51011051--this family is not in food stamp program 
* (by their own report AND by the administrative records)

*In the first lines of this code, we drop id# 70016008 which appears twice--once as a check recipient and 
*once as a stamp recipient.  It is obviously the same record (looking at the ages
*on the roster and other HH data) and there is no way to tell which is correct.

#delimit;
clear;
use sandiego2a.dta;
drop if case_id==70016008;

*The constraint variables equal one if a household reports spending less on food
than they receive in food stamps;
*Notice that food expenditure (amtpaid) data is weekly;
gen newstamp=chekstam==2;
gen con1=(52*amtpaid/12)<fs_amt1;
gen con2=(52*amtpaid/12)<(fs_amt1+fs_amt2);
gen con1s=con1*(newstamp==1);
tab con1s newstamp;
gen con1c=con1*(newstamp==0);
tab con1c newstamp; 
tab con1 newstamp; 
gen con2s=con2*newstamp==1;
tab con2s newstamp;

tab newstamp con1; 
gen fexp_pp=amtpaid/sizefcu;
gen fexp_pp_s=fexp_pp if newstamp==1;
gen fexp_pp_c=fexp_pp if newstamp==0;

*Table 1;
sum fexp_pp_s fexp_pp_c;
ttest fexp_pp_s=fexp_pp_c, unpaired level(90);

gen fexp_pame=amtpaid/ener_enu;
gen fexp_pame_s=fexp_pame if newstamp==1;
gen fexp_pame_c=fexp_pame if newstamp==0;
sum fexp_pame_s fexp_pame_c;
ttest fexp_pame_s=fexp_pame_c, unpaired level(90);

*Table 1 for single and multiple-adult households;
sort sindum1h;
by sindum1h: ttest fexp_pp_s=fexp_pp_c if con1==0, unpaired level(90);
by sindum1h: ttest fexp_pame_s=fexp_pame_c if con1==0, unpaired level(90);

zz;

*Table A1--descriptive statistics;
sum fcu_inc if newstamp==1 & con1s==0; 
sum fcu_inc if newstamp==1 & con1s==1; 
sum fcu_inc if newstamp==1;
sum fcu_inc if newstamp==0;

sum fs_amt1 if newstamp==1 & con1s==0; 
sum fs_amt1 if newstamp==1 & con1s==1; 
sum fs_amt1 if newstamp==1;
sum fs_amt1 if newstamp==0;

gen prop=fs_amt1/(fcu_inc+fs_amt1);
sum prop if newstamp==1 & con1s==0; 
sum prop if newstamp==1 & con1s==1; 
sum prop if newstamp==1;
sum prop if newstamp==0;

gen fexp_mthly=(52*amtpaid/12);
sum fexp_mthly if newstamp==1 & con1s==0; 
sum fexp_mthly if newstamp==1 & con1s==1; 
sum fexp_mthly if newstamp==1;
sum fexp_mthly if newstamp==0;

gen yeswic=100*(amtwic > 0);
sum yeswic if newstamp==1 & con1s==0;
sum yeswic if newstamp==1 & con1s==1; 
sum yeswic if newstamp==1;
sum yeswic if newstamp==0;

gen amtwic_mthly=amtwic*52/12;
sum amtwic_mthly if newstamp==1 & con1s==0; 
sum amtwic_mthly if newstamp==1 & con1s==1; 
sum amtwic_mthly if newstamp==1;
sum amtwic_mthly if newstamp==0;

sum amtwic_mthly if newstamp==1 & con1s==0 & yeswic==100; 
sum amtwic_mthly if newstamp==1 & con1s==1 & yeswic==100; 
sum amtwic_mthly if newstamp==1 & yeswic==100;
sum amtwic_mthly if newstamp==0 & yeswic==100;

gen yesgift=100*(amtgift > 0);
sum yesgift if newstamp==1 & con1s==0;
sum yesgift if newstamp==1 & con1s==1; 
sum yesgift if newstamp==1;
sum yesgift if newstamp==0;

gen amtgift_mthly=amtgift*52/12;
sum amtgift_mthly if newstamp==1 & con1s==0; 
sum amtgift_mthly if newstamp==1 & con1s==1; 
sum amtgift_mthly if newstamp==1;
sum amtgift_mthly if newstamp==0;

sum amtgift_mthly if newstamp==1 & con1s==0 & yesgift==100; 
sum amtgift_mthly if newstamp==1 & con1s==1 & yesgift==100; 
sum amtgift_mthly if newstamp==1 & yesgift==100;
sum amtgift_mthly if newstamp==0 & yesgift==100;

gen yesbrk=100*(subbreak > 0);
sum yesbrk if newstamp==1 & con1s==0;
sum yesbrk if newstamp==1 & con1s==1; 
sum yesbrk if newstamp==1;
sum yesbrk if newstamp==0;

gen subbreak_pk=subbreak/numkid1h;
sum subbreak_pk if newstamp==1 & con1s==0 & yesbrk==100;
sum subbreak_pk if newstamp==1 & con1s==1 & yesbrk==100; 
sum subbreak_pk if newstamp==1 & yesbrk==100;
sum subbreak_pk if newstamp==0 & yesbrk==100;

gen yeslunch=100*(sublunch > 0);
sum yeslunch if newstamp==1 & con1s==0;
sum yeslunch if newstamp==1 & con1s==1; 
sum yeslunch if newstamp==1;
sum yeslunch if newstamp==0;

gen sublunch_pk=sublunch/numkid1h;
sum sublunch_pk if newstamp==1 & con1s==0 & yeslunch==100;
sum sublunch_pk if newstamp==1 & con1s==1 & yeslunch==100; 
sum sublunch_pk if newstamp==1 & yeslunch==100;
sum sublunch_pk if newstamp==0 & yeslunch==100;

gen asguest=totasgst/newhhsiz;
gen byguest=totbygst/newhhsiz;

sum asguest if newstamp==1 & con1s==0;
sum asguest if newstamp==1 & con1s==1;
sum asguest if newstamp==1;
sum asguest if newstamp==0;

sum byguest if newstamp==1 & con1s==0;
sum byguest if newstamp==1 & con1s==1;
sum byguest if newstamp==1;
sum byguest if newstamp==0;

gen head_emp=100*(sampemp==1);
sum head_emp if newstamp==1 & con1s==0;
sum head_emp if newstamp==1 & con1s==1;
sum head_emp if newstamp==1;
sum head_emp if newstamp==0;

gen head_asian=100*(q1_1f==1);
sum head_asian if newstamp==1 & con1s==0;
sum head_asian if newstamp==1 & con1s==1;
sum head_asian if newstamp==1;
sum head_asian if newstamp==0;

gen head_hisp=100*(q1_1f==2);
sum head_hisp if newstamp==1 & con1s==0;
sum head_hisp if newstamp==1 & con1s==1;
sum head_hisp if newstamp==1;
sum head_hisp if newstamp==0;

gen head_black=100*(q1_1f==3);
sum head_black if newstamp==1 & con1s==0;
sum head_black if newstamp==1 & con1s==1;
sum head_black if newstamp==1;
sum head_black if newstamp==0;

gen head_married=100*(q1_1e==1);
sum head_married if newstamp==1 & con1s==0;
sum head_married if newstamp==1 & con1s==1;
sum head_married if newstamp==1;
sum head_married if newstamp==0;

gen head_married2=100*head_married*(rel2==1);
sum head_married2 if newstamp==1 & con1s==0;
sum head_married2 if newstamp==1 & con1s==1;
sum head_married2 if newstamp==1;
sum head_married2 if newstamp==0;

sum sizefcu if newstamp==1 & con1s==0;
sum sizefcu if newstamp==1 & con1s==1;
sum sizefcu if newstamp==1;
sum sizefcu if newstamp==0;

sum newhhsiz if newstamp==1 & con1s==0;
sum newhhsiz if newstamp==1 & con1s==1;
sum newhhsiz if newstamp==1;
sum newhhsiz if newstamp==0;

sum femheadh if newstamp==1 & con1s==0;
sum femheadh if newstamp==1 & con1s==1;
sum femheadh if newstamp==1;
sum femheadh if newstamp==0;

sum sindum1h if newstamp==1 & con1s==0;
sum sindum1h  if newstamp==1 & con1s==1;
sum sindum1h  if newstamp==1;
sum sindum1h if newstamp==0;

sum kiddum1h if newstamp==1 & con1s==0;
sum kiddum1h  if newstamp==1 & con1s==1;
sum kiddum1h  if newstamp==1;
sum kiddum1h if newstamp==0;

gen temp=(sindum1h==1)*(femheadh==1)*(kiddum1h==1);
sum temp if newstamp==1 & con1s==0;
sum temp  if newstamp==1 & con1s==1;
sum temp if newstamp==1;
sum temp if newstamp==0;

sum numkid1h if newstamp==1 & con1s==0 & kiddum1h==1;
sum numkid1h  if newstamp==1 & con1s==1 & kiddum1h==1;
sum numkid1h if newstamp==1 & kiddum1h==1;
sum numkid1h if newstamp==0 & kiddum1h==1;

sort newstamp;
by newstamp: tab famtypeh;
tab famtypeh if newstamp==1 & con1s==0;


**************************************************************;

*  Second part:  descriptive statistics on regression sample  

**************************************************************;

drop if newstamp==0;
drop if con1s==1;

codebook case_id;

gen fshare=(52/12)*amtpaid/(fcu_inc+fs_amt1);
sum fshare;
drop if fshare > 1;
codebook case_id;
sort sindum1h;

*More Table A1--descriptive statistics on regression sample;
by sindum1h: sum fcu_inc fs_amt1 prop fexp_mthly yeswic yesgift yesbrk yeslunch asguest byguest head_emp head_asian head_hisp head_black;
by sindum1h: sum head_married head_married2 newhhsiz sizefcu femheadh kiddum1h;

by sindum1h: sum amtwic_mthly if yeswic==100;
by sindum1h: sum amtgift_mthly if yesgift==100;
by sindum1h: sum subbreak_pk if yesbrk==100;
by sindum1h: sum sublunch_pk if yeslunch==100;
by sindum1h: sum numkid1h if kiddum1h==1;

by sindum1h: tab famtypeh;

clear;
use C:\bob\research\CASHOUT\cashoutdisk\sandiego2a.dta;
drop if case_id==70016008;

codebook case_id;

set type double;
gen id=case_id;
gen stamp=chekstam==2;
gen fexp=amtpaid;
gen giftfood=amtgift;
gen wicfood=amtwic;
gen cashinc=fcu_inc*12/52;
gen fsb=fs_amt1*12/52;
gen head_asian=q1_1f==1;
gen subbreak_pk=12*subbreak/(52*numkid1h);
replace subbreak_pk=0 if numkid1h==0;
gen sublunch_pk=12*sublunch/(52*numkid1h);
replace sublunch_pk=0 if numkid1h==0;
gen subbreak_pp=12*subbreak/(52*newhhsiz);
replace subbreak_pp=0 if newhhsiz==0;
gen sublunch_pp=12*sublunch/(52*newhhsiz);
replace sublunch_pp =0 if newhhsiz==0;
gen femhead=femheadh;
gen single_head=sindum1h;
gen h2_17=h2_5+h6_11+h12_17;
gen h61p=h61_65+h66p;
gen asguest=totasgst;
gen byguest=totbygst;

keep id stamp fexp newhhsiz sizefcu giftfood wicfood cashinc fsb head_asian subbreak_pk sublunch_pk subbreak_pp sublunch_pp
femhead single_head h0_1 h2_17 h61p asguest byguest;

save outdata, replace;
clear;
log close;
